@@ -43,7 +43,11 @@ class FileProcessor(ABC):
                 data.append(f_entry)
             else:
                 sysout(f'Uploading files from "{f_path}" to Firebase ...')
-                for file in next(os.walk(f_path))[2]:
+                all_files = next(os.walk(f_path))[2]
+                print('Cur Dir: ' + os.getcwd())
+                print(' Target: ' + f_path)
+                print('  Files: [' + '  '.join(all_files) + ']')
+                for file in all_files:
                     filename = os.path.join(f_path, file)
                     if os.path.isfile(filename) and fnmatch(file, glob_exp):
                         f_entry = FileProcessor._read_and_encode(filename)
